/***************************************************************************
*   Copyright 2007 Niko Sams <niko.sams@gmail.com>                        *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************/

#include "kdevuploadplugin.h"
#include "uploaddialog.h"

#include <QAction>

#include <kpluginfactory.h>
#include <kpluginloader.h>
#include <context.h>

#include <kdebug.h>
#include <klocale.h>
#include <kparts/mainwindow.h>

#include <icore.h>
#include <iproject.h>
#include <iprojectcontroller.h>
#include <iuicontroller.h>
#include <projectmodel.h>

K_PLUGIN_FACTORY(UploadFactory, registerPlugin<UploadPlugin>(); )
K_EXPORT_PLUGIN(UploadFactory("kdevupload"))

UploadPlugin::UploadPlugin(QObject *parent, const QVariantList &)
: KDevelop::IPlugin(UploadFactory::componentData(), parent)
{
}

UploadPlugin::~UploadPlugin()
{
}


void UploadPlugin::unload()
{
}

QPair<QString,QList<QAction*> > UploadPlugin::requestContextMenuActions(KDevelop::Context* context)
{
    if (context->type() == KDevelop::Context::ProjectItemContext) {
        KDevelop::ProjectItemContext *itemCtx = dynamic_cast<KDevelop::ProjectItemContext*>(context);
        if (itemCtx) {
            m_ctxUrlList.clear();
            Q_FOREACH (KDevelop::ProjectBaseItem* _item, itemCtx->items()) {
                if (_item->folder() || _item->file()) {
                    m_ctxUrlList << _item;
                }
            }
            if (!m_ctxUrlList.isEmpty()) {
                QList<QAction*> actions;
                QAction *action;
                action = new QAction(i18n("Upload File..."), this);
                connect(action, SIGNAL(triggered()), this, SLOT(upload()));
                actions << action;

                return qMakePair(QString("Upload"), actions);
            }
        }
    }
    return KDevelop::IPlugin::requestContextMenuActions(context);
}

void UploadPlugin::upload()
{
    kDebug() << m_ctxUrlList;

    if (m_ctxUrlList.isEmpty()) return;
    KDevelop::IProject* project = m_ctxUrlList.at(0)->project();

    UploadDialog dialog(this, project, core()->uiController()->activeMainWindow());
    dialog.setRootItem(m_ctxUrlList.at(0));
    dialog.exec();
}

#include "kdevuploadplugin.moc"
// kate: space-indent on; indent-width 4; tab-width 4; replace-tabs on
