/***************************************************************************
*   Copyright 2007 Niko Sams <niko.sams@gmail.com>                        *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************/
#include "uploadpreferences.h"
#include "uploadprofilemodel.h"
#include "ui_uploadpreferences.h"
#include "uploadprofiledlg.h"
#include "uploadprofileitem.h"

#include <QVBoxLayout>
#include <QStandardItemModel>

#include <kpluginfactory.h>
#include <kpluginloader.h>
#include <ksharedconfig.h>
#include <kconfig.h>
#include <kconfiggroup.h>
#include <kurl.h>

#include <core.h>
#include <iprojectcontroller.h>
#include <iproject.h>

using namespace KDevelop;

K_PLUGIN_FACTORY(UploadPreferencesFactory, registerPlugin<UploadPreferences>(); )
K_EXPORT_PLUGIN(UploadPreferencesFactory("kcm_kdev_upload"))

UploadPreferences::UploadPreferences( QWidget *parent, const QVariantList &args )
    : KCModule( UploadPreferencesFactory::componentData(), parent, args )
{
    m_config = KSharedConfig::openConfig( args.at(0).toString() ); //developer settings
    m_config->addConfigSources(QStringList() << args.at(1).toString()); //project settings
    m_config->reparseConfiguration();

    setButtons(Help | Apply);

    QVBoxLayout * l = new QVBoxLayout( this );
    setLayout(l);
    QWidget* w = new QWidget();
    l->addWidget(w);

    m_ui = new Ui::UploadPreferences();
    m_ui->setupUi(w);

    m_model = new UploadProfileModel;
    KConfigGroup group = m_config->group("Upload");
    m_model->setConfig(group);
    m_ui->profilesList->setModel(m_model);

    connect(m_model, SIGNAL(dataChanged(QModelIndex, QModelIndex)),
            this, SLOT(changed()));

    connect(m_ui->addProfileButton, SIGNAL(clicked()),
              this, SLOT(addProfile()));
    connect(m_ui->modifyProfileButton, SIGNAL(clicked()),
              this, SLOT(modifyProfile()));
    connect(m_ui->removeProfileButton, SIGNAL(clicked()),
              this, SLOT(removeProfile()));
    connect(m_ui->profilesList, SIGNAL(doubleClicked(QModelIndex)),
            this, SLOT(modifyProfile()));

    m_dlg = new UploadProfileDlg(this);
}

UploadPreferences::~UploadPreferences( )
{
  delete m_ui;
}

void UploadPreferences::save()
{
    m_model->submit();
}

void UploadPreferences::load()
{
    m_model->revert();
}

void UploadPreferences::addProfile()
{
    UploadProfileItem* i = new UploadProfileItem();
    m_model->appendRow(i);
    if (m_dlg->editProfile(i) == QDialog::Rejected) {
        m_model->removeRow(i->index().row());
    }
}

void UploadPreferences::removeProfile()
{
    Q_FOREACH(QModelIndex index, m_ui->profilesList->selectionModel()->selectedIndexes()) {
        m_model->removeRow(index.row());
    }
}

void UploadPreferences::modifyProfile()
{
    Q_FOREACH(QModelIndex index, m_ui->profilesList->selectionModel()->selectedIndexes()) {
        UploadProfileItem* i = m_model->uploadItem(index);
        if (i) {
            m_dlg->editProfile(i);
        }
    }
}

#include "uploadpreferences.moc"
// kate: space-indent on; indent-width 4; tab-width 4; replace-tabs on
